Tutorial
==================

Just follow the link to the example notebooks.


  * `Cartesian <http://nbviewer.jupyter.org/github/mcocdawc/chemcoord/blob/v2.1.1/Tutorial/Cartesian.ipynb>`_
  * `Zmat <http://nbviewer.jupyter.org/github/mcocdawc/chemcoord/blob/v2.1.1/Tutorial/Zmat.ipynb>`_
  * `Transformation <http://nbviewer.jupyter.org/github/mcocdawc/chemcoord/blob/v2.1.1/Tutorial/Transformation.ipynb>`_
  * `Gradients <http://nbviewer.jupyter.org/github/mcocdawc/chemcoord/blob/v2.1.1/Tutorial/Gradients.ipynb>`_
  * `Advanced customisation <http://nbviewer.jupyter.org/github/mcocdawc/chemcoord/blob/v2.1.1/Tutorial/Advanced_customisation.ipynb>`_

If you want to have an interactive session, just download the following
`zip file <https://minhaskamal.github.io/DownGit/#/home?url=https://github.com/mcocdawc/chemcoord/tree/v2.1.1/Tutorial>`_,
which contains all notebooks and coordinates.
